==> python-traits_3.0.3.orig.tar.gz: Traits-3.0.3/enthought/traits/ui/editors/time_editor.py <==
#------------------------------------------------------------------------------
#
#  Copyright (c) 2008, Enthought, Inc.
#  All rights reserved.
#  
#  This software is provided without warranty under the terms of the BSD
#  license included in enthought/LICENSE.txt and may be redistributed only
#  under the conditions described in the aforementioned license.  The license
#  is also available online at http://www.enthought.com/licenses/BSD.txt
#
#  Thanks for using Enthought open source!
#  
#  Author: Judah De Paula
#  Date:   10/7/2008
#
#------------------------------------------------------------------------------
"""
A Traits UI editor that wraps a WX timer control.
"""
import datetime

from enthought.traits.api import Property
from enthought.traits.ui.basic_editor_factory import BasicEditorFactory
from enthought.traits.ui.toolkit import toolkit_object   


#-- TimeEditor definition ----------------------------------------------------- 
class TimeEditor ( BasicEditorFactory ):
    """
    Editor factory for time editors.  Generates _TimeEditor()s.
    """

    # The editor class to be created:
    klass = Property
    
    #---------------------------------------------------------------------------
    #  Property getters
    #---------------------------------------------------------------------------
    def _get_klass(self):
        """ Returns the editor class to be created.
        """
        return toolkit_object('time_editor:_TimeEditor')
#-- end TimeEditor definition ------------------------------------------------- 


#-- eof -----------------------------------------------------------------------

==> python-traits_3.2.0.orig.tar.gz: Traits-3.2.0/enthought/traits/ui/editors/time_editor.py <==
#------------------------------------------------------------------------------
#
#  Copyright (c) 2008, Enthought, Inc.
#  All rights reserved.
#  
#  This software is provided without warranty under the terms of the BSD
#  license included in enthought/LICENSE.txt and may be redistributed only
#  under the conditions described in the aforementioned license.  The license
#  is also available online at http://www.enthought.com/licenses/BSD.txt
#
#  Thanks for using Enthought open source!
#  
#  Author: Judah De Paula
#  Date:   10/7/2008
#
#------------------------------------------------------------------------------
"""
A Traits UI editor that wraps a WX timer control.
"""
from enthought.traits.api import Str
from enthought.traits.ui.editor_factory import EditorFactory
from enthought.traits.ui.ui_traits import AView


#-- TimeEditor definition ----------------------------------------------------- 
class TimeEditor ( EditorFactory ):
    """
    Editor factory for time editors.  Generates _TimeEditor()s.
    """

    #---------------------------------------------------------------------------
    #  Trait definitions:  
    #---------------------------------------------------------------------------
    
    #-- ReadonlyEditor traits -------------------------------------------------- 
    
    # Message to show when Time is None.
    message = Str('Undefined')
    
    # The string representation of the time to show.  Uses time.strftime format.
    strftime = Str('%I:%M:%S %p')
    
    # An optional view to display when a read-only text editor is clicked:
    view = AView
    
#-- end TimeEditor definition ------------------------------------------------- 


#-- eof -----------------------------------------------------------------------
